==> openshift-model-hive-5.12.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncSetListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SyncSetListBuilder extends io.fabric8.openshift.api.model.hive.v1.SyncSetListFluentImpl<io.fabric8.openshift.api.model.hive.v1.SyncSetListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.SyncSetList,io.fabric8.openshift.api.model.hive.v1.SyncSetListBuilder>{
  public SyncSetListBuilder() {
    this(false);
  }
  public SyncSetListBuilder(java.lang.Boolean validationEnabled) {
    this(new SyncSetList(), validationEnabled);
  }
  public SyncSetListBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetListFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncSetListBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SyncSetList(), validationEnabled);
  }
  public SyncSetListBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetListFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncSetList instance) {
    this(fluent, instance, false);
  }
  public SyncSetListBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetListFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncSetList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncSetListBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetList instance) {
    this(instance,false);
  }
  public SyncSetListBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.SyncSetListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.SyncSetList build() {
    SyncSetList buildable = new SyncSetList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SyncSetListBuilder that = (SyncSetListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncSetListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SyncSetListBuilder extends SyncSetListFluentImpl<SyncSetListBuilder> implements VisitableBuilder<SyncSetList,SyncSetListBuilder>{
  public SyncSetListBuilder() {
    this(false);
  }
  public SyncSetListBuilder(Boolean validationEnabled) {
    this(new SyncSetList(), validationEnabled);
  }
  public SyncSetListBuilder(SyncSetListFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncSetListBuilder(SyncSetListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SyncSetList(), validationEnabled);
  }
  public SyncSetListBuilder(SyncSetListFluent<?> fluent,SyncSetList instance) {
    this(fluent, instance, false);
  }
  public SyncSetListBuilder(SyncSetListFluent<?> fluent,SyncSetList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncSetListBuilder(SyncSetList instance) {
    this(instance,false);
  }
  public SyncSetListBuilder(SyncSetList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SyncSetListFluent<?> fluent;
  Boolean validationEnabled;
  public SyncSetList build() {
    SyncSetList buildable = new SyncSetList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
